import DatePicker from '../../assets/air-datepicker';
export class AirDatePicker {
    constructor() {
        this.classes = '';
        this.inline = false;
        this.language = 'en'; // We are shipping English as a default language not Russian
        this.startDate = new Date();
        this.firstDay = '';
        this.weekends = [6, 0];
        this.dateFormat = '';
        this.altField = '';
        this.altFieldDateFormat = '@';
        this.toggleSelected = true;
        this.keyboardNav = true;
        this.position = 'bottom left';
        this.offset = 12;
        this.view = 'days';
        this.minView = 'days';
        this.showOtherMonths = true;
        this.selectOtherMonths = true;
        this.moveToOtherMonthsOnSelect = true;
        this.showOtherYears = true;
        this.selectOtherYears = true;
        this.moveToOtherYearsOnSelect = true;
        this.minDate = '';
        this.maxDate = '';
        this.disableNavWhenOutOfRange = true;
        this.multipleDates = false;
        this.multipleDatesSeparator = ';';
        this.range = false;
        this.todayButton = false;
        this.clearButton = false;
        this.showEvent = 'focus';
        this.timepicker = false;
        this.onlyTimepicker = false;
        this.dateTimeSeparator = ' ';
        this.timeFormat = '';
        this.minHours = 0;
        this.maxHours = 24;
        this.minMinutes = 0;
        this.maxMinutes = 59;
        this.hoursStep = 1;
        this.minutesStep = 1;
    }
    componentDidLoad() {
        /**
         * I dinamiclly load jQuery into application if its not yet defined inside global
         * scope. This eliminates an extra step if you dont have jQuery already and if you
         * do we will just use yours.
         */
        this.loadjQuery(() => {
            const $ = window.jQuery;
            DatePicker(window, $);
            this.addEnglishTranslation($);
            this._picker = $(this.element.querySelector('input'))
                .datepicker({
                classes: this.classes,
                inline: this.inline,
                language: this.language,
                startDate: this.startDate,
                firstDay: this.firstDay,
                weekends: this.weekends,
                dateFormat: this.dateFormat,
                altField: this.altField,
                altFieldDateFormat: this.altFieldDateFormat,
                toggleSelected: this.toggleSelected,
                keyboardNav: this.keyboardNav,
                position: this.position,
                offset: this.offset,
                view: this.view,
                minView: this.minView,
                showOtherMonths: this.showOtherMonths,
                selectOtherMonths: this.selectOtherMonths,
                moveToOtherMonthsOnSelect: this.moveToOtherMonthsOnSelect,
                showOtherYears: this.showOtherYears,
                selectOtherYears: this.selectOtherYears,
                moveToOtherYearsOnSelect: this.moveToOtherYearsOnSelect,
                minDate: this.minDate,
                maxDate: this.maxDate,
                disableNavWhenOutOfRange: this.disableNavWhenOutOfRange,
                multipleDates: this.multipleDates,
                multipleDatesSeparator: this.multipleDatesSeparator,
                range: this.range,
                todayButton: this.todayButton,
                clearButton: this.clearButton,
                showEvent: this.showEvent,
                autoClose: this.autoClose,
                monthsField: this.monthsField,
                timepicker: this.timepicker,
                onlyTimepicker: this.onlyTimepicker,
                dateTimeSeparator: this.dateTimeSeparator,
                timeFormat: this.timeFormat,
                minHours: this.minHours,
                maxHours: this.maxHours,
                minMinutes: this.minMinutes,
                maxMinutes: this.maxMinutes,
                hoursStep: this.hoursStep,
                minutesStep: this.minutesStep,
                onSelect: (formattedDate, date, inst) => this.onSelect.emit({ formattedDate, date, inst }),
                onShow: (inst, animationCompleted) => this.onShow.emit({ inst, animationCompleted }),
                onHide: (inst, animationCompleted) => this.onHide.emit({ inst, animationCompleted }),
                onChangeMonth: (month, year) => this.onChangeMonth.emit({ month, year }),
                onChangeYear: (year) => this.onChangeYear.emit({ year }),
                onChangeDecade: (decade) => this.onChangeDecade.emit({ decade }),
                onChangeView: (view) => this.onChangeView.emit({ view }),
                onRenderCell: (date, cellType) => this.onRenderCell.emit({ date, cellType })
            })
                .data('datepicker');
        });
    }
    show() {
        this._picker.show();
    }
    hide() {
        this._picker.hide();
    }
    destroy() {
        this._picker.destroy();
    }
    next() {
        this._picker.next();
    }
    prev() {
        this._picker.prev();
    }
    selectDate(date) {
        this._picker.selectDate(date);
    }
    removeDate(date) {
        this._picker.removeDate(date);
    }
    clear() {
        this._picker.clear();
    }
    update(field, value) {
        this._picker.show(field, value);
    }
    setView(view) {
        this._picker.view = view;
    }
    setDate(date) {
        this._picker.date = date;
    }
    getElement() {
        return this._picker.$el;
    }
    getSelectedDates() {
        return this._picker.selectedDates;
    }
    loadjQuery(callback) {
        const jQuery = window.jQuery;
        if (!jQuery) {
            const link = 'https://code.jquery.com/jquery-3.3.1.min.js';
            let element = document.createElement('script');
            element.setAttribute('type', 'text/javascript');
            element.setAttribute('src', link);
            element.onload = callback;
            element.onreadystatechange = callback;
            document.head.appendChild(element);
        }
        else {
            callback();
        }
    }
    addEnglishTranslation(jQuery) {
        jQuery.fn.datepicker.language['en'] = {
            days: ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'],
            daysShort: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
            daysMin: ['Su', 'Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa'],
            months: [
                'January',
                'February',
                'March',
                'April',
                'May',
                'June',
                'July',
                'August',
                'September',
                'October',
                'November',
                'December'
            ],
            monthsShort: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
            today: 'Today',
            clear: 'Clear',
            dateFormat: 'mm/dd/yyyy',
            timeFormat: 'hh:ii aa',
            firstDay: 0
        };
    }
    static get is() { return "air-datepicker"; }
    static get properties() { return {
        "altField": {
            "type": String,
            "attr": "alt-field"
        },
        "altFieldDateFormat": {
            "type": String,
            "attr": "alt-field-date-format"
        },
        "autoClose": {
            "type": Boolean,
            "attr": "auto-close"
        },
        "classes": {
            "type": String,
            "attr": "classes"
        },
        "clear": {
            "method": true
        },
        "clearButton": {
            "type": Boolean,
            "attr": "clear-button"
        },
        "dateFormat": {
            "type": String,
            "attr": "date-format"
        },
        "dateTimeSeparator": {
            "type": String,
            "attr": "date-time-separator"
        },
        "destroy": {
            "method": true
        },
        "disableNavWhenOutOfRange": {
            "type": Boolean,
            "attr": "disable-nav-when-out-of-range"
        },
        "element": {
            "elementRef": true
        },
        "firstDay": {
            "type": String,
            "attr": "first-day"
        },
        "getElement": {
            "method": true
        },
        "getSelectedDates": {
            "method": true
        },
        "hide": {
            "method": true
        },
        "hoursStep": {
            "type": Number,
            "attr": "hours-step"
        },
        "inline": {
            "type": Boolean,
            "attr": "inline"
        },
        "keyboardNav": {
            "type": Boolean,
            "attr": "keyboard-nav"
        },
        "language": {
            "type": String,
            "attr": "language"
        },
        "maxDate": {
            "type": String,
            "attr": "max-date"
        },
        "maxHours": {
            "type": Number,
            "attr": "max-hours"
        },
        "maxMinutes": {
            "type": Number,
            "attr": "max-minutes"
        },
        "minDate": {
            "type": String,
            "attr": "min-date"
        },
        "minHours": {
            "type": Number,
            "attr": "min-hours"
        },
        "minMinutes": {
            "type": Number,
            "attr": "min-minutes"
        },
        "minutesStep": {
            "type": Number,
            "attr": "minutes-step"
        },
        "minView": {
            "type": String,
            "attr": "min-view"
        },
        "monthsField": {
            "type": String,
            "attr": "months-field"
        },
        "moveToOtherMonthsOnSelect": {
            "type": Boolean,
            "attr": "move-to-other-months-on-select"
        },
        "moveToOtherYearsOnSelect": {
            "type": Boolean,
            "attr": "move-to-other-years-on-select"
        },
        "multipleDates": {
            "type": "Any",
            "attr": "multiple-dates"
        },
        "multipleDatesSeparator": {
            "type": String,
            "attr": "multiple-dates-separator"
        },
        "next": {
            "method": true
        },
        "offset": {
            "type": Number,
            "attr": "offset"
        },
        "onlyTimepicker": {
            "type": Boolean,
            "attr": "only-timepicker"
        },
        "position": {
            "type": String,
            "attr": "position"
        },
        "prev": {
            "method": true
        },
        "range": {
            "type": Boolean,
            "attr": "range"
        },
        "removeDate": {
            "method": true
        },
        "selectDate": {
            "method": true
        },
        "selectOtherMonths": {
            "type": Boolean,
            "attr": "select-other-months"
        },
        "selectOtherYears": {
            "type": Boolean,
            "attr": "select-other-years"
        },
        "setDate": {
            "method": true
        },
        "setView": {
            "method": true
        },
        "show": {
            "method": true
        },
        "showEvent": {
            "type": String,
            "attr": "show-event"
        },
        "showOtherMonths": {
            "type": Boolean,
            "attr": "show-other-months"
        },
        "showOtherYears": {
            "type": Boolean,
            "attr": "show-other-years"
        },
        "startDate": {
            "type": "Any",
            "attr": "start-date"
        },
        "timeFormat": {
            "type": String,
            "attr": "time-format"
        },
        "timepicker": {
            "type": Boolean,
            "attr": "timepicker"
        },
        "todayButton": {
            "type": Boolean,
            "attr": "today-button"
        },
        "toggleSelected": {
            "type": Boolean,
            "attr": "toggle-selected"
        },
        "update": {
            "method": true
        },
        "view": {
            "type": String,
            "attr": "view"
        },
        "weekends": {
            "type": "Any",
            "attr": "weekends"
        }
    }; }
    static get events() { return [{
            "name": "onSelect",
            "method": "onSelect",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "onShow",
            "method": "onShow",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "onHide",
            "method": "onHide",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "onChangeMonth",
            "method": "onChangeMonth",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "onChangeYear",
            "method": "onChangeYear",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "onChangeDecade",
            "method": "onChangeDecade",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "onChangeView",
            "method": "onChangeView",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "onRenderCell",
            "method": "onRenderCell",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
    static get style() { return "/**style-placeholder:air-datepicker:**/"; }
}
